searchData={"content_type":"text/markdown","items":[{"doc":"The behaviour defining the dynamic config provider.\n\n`Kungfuig` provides a plugagble drop-in support for live configurations.\n\n#","ref":"Kungfuig.html","title":"Kungfuig","type":"behaviour"},{"doc":"Kungfuig.Supervisor.start_link()\n    Kungfuig.config()\n    #⇒ %{env: %{kungfuig: []}, system: %{}}\n\n    Kungfuig.config(:env)\n    #⇒ %{kungfuig: []}\n\n    Application.put_env(:kungfuig, :foo, 42)\n    Kungfuig.config(:env)\n    #⇒ %{kungfuig: [foo: 42]}\n\nThe configuration is frequently updated.","ref":"Kungfuig.html#module-examples","title":"Examples - Kungfuig","type":"behaviour"},{"doc":"The config that is manages by this behaviour is a simple map","ref":"Kungfuig.html#__struct__/0","title":"Kungfuig.__struct__/0","type":"function"},{"doc":"","ref":"Kungfuig.html#config/2","title":"Kungfuig.config/2","type":"function"},{"doc":"","ref":"Kungfuig.html#c:start_link/1","title":"Kungfuig.start_link/1","type":"callback"},{"doc":"The actual implementation to update the config","ref":"Kungfuig.html#c:update_config/1","title":"Kungfuig.update_config/1","type":"callback"},{"doc":"The callback to be used for subscibing to config updates.\n\nMight be an anonymous function, an `{m, f}` tuple accepting a single argument,\nor a process identifier accepting `call`, `cast` or simple message (`:info`.)","ref":"Kungfuig.html#t:callback/0","title":"Kungfuig.callback/0","type":"type"},{"doc":"The config map to be updated and exposed through callback","ref":"Kungfuig.html#t:config/0","title":"Kungfuig.config/0","type":"type"},{"doc":"The option that can be passed to `start_link/1` function","ref":"Kungfuig.html#t:option/0","title":"Kungfuig.option/0","type":"type"},{"doc":"The `start_link/1` function wrapping the `GenServer.start_link/3`","ref":"Kungfuig.html#t:t/0","title":"Kungfuig.t/0","type":"type"},{"doc":"The scaffold for the backend watching the external config source.","ref":"Kungfuig.Backend.html","title":"Kungfuig.Backend","type":"behaviour"},{"doc":"The implementation of the call to remote that retrieves the data","ref":"Kungfuig.Backend.html#c:get/1","title":"Kungfuig.Backend.get/1","type":"callback"},{"doc":"The key this particular config would be stored under, defaults to module name","ref":"Kungfuig.Backend.html#c:key/0","title":"Kungfuig.Backend.key/0","type":"callback"},{"doc":"The implementation of error reporting","ref":"Kungfuig.Backend.html#c:report/1","title":"Kungfuig.Backend.report/1","type":"callback"},{"doc":"The transformer that converts the retrieved data to internal representation","ref":"Kungfuig.Backend.html#c:transform/1","title":"Kungfuig.Backend.transform/1","type":"callback"},{"doc":"Generic validator encapsulation.\n\nDefault implementation is\n  [`NimbleOptions`](https://github.com/dashbitco/nimble_options).","ref":"Kungfuig.Validator.html","title":"Kungfuig.Validator","type":"behaviour"},{"doc":"Generates a documentation for expected options","ref":"Kungfuig.Validator.html#c:doc/1","title":"Kungfuig.Validator.doc/1","type":"callback"},{"doc":"Validates given options with the schema, provided by the implementation of this behaviour","ref":"Kungfuig.Validator.html#c:validate/1","title":"Kungfuig.Validator.validate/1","type":"callback"},{"doc":"# ![Kungfuig](https://raw.githubusercontent.com/kantox/kungfuig/master/stuff/kungfuig-48x48.png) Kungfuig    [![Kantox ❤ OSS](https://img.shields.io/badge/❤-kantox_oss-informational.svg)](https://kantox.com/)  ![Test](https://github.com/kantox/kungfuig/workflows/Test/badge.svg)  ![Dialyzer](https://github.com/kantox/kungfuig/workflows/Dialyzer/badge.svg)","ref":"readme.html","title":"Kungfuig","type":"extras"},{"doc":"Live config supporting many different backends.\n\n**Kungfuig** (_pronounced:_ [ˌkʌŋˈfig]) provides an easy way to plug\nlive configuration into everything.\n\nIt provides backends for `env` and `system` and supports custom backends.","ref":"readme.html#intro","title":"Intro - Kungfuig","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:kungfuig, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Kungfuig","type":"extras"},{"doc":"**Kungfuig** is the easy way to read the external configuration from sources that are not controlled by the application using it, such as _Redis_, or _Database_.\n\nHere is the example of backend implementation for the config read from external _MySQL_.\n\n```elixir\ndefmodule MyApp.Kungfuig.MySQL do\n  @moduledoc false\n\n  use Kungfuig.Backend\n\n  @impl Kungfuig.Backend\n  def get(_meta) do\n    with {:ok, host}   Flow.from_enumerable()\n        |> Flow.map(fn [_, field1, field2, _, _] -> {field1, field2} end)\n        |> Flow.partition(key: &elem(&1, 0))\n        |> Flow.reduce(fn -> %{} end, fn {field1, field2}, acc ->\n          Map.update(\n            acc,\n            String.to_existing_atom(field1),\n            [field2],\n            &[field2 | &1]\n          )\n        end)\n\n      Logger.info(\"Loaded #{Enum.count(result)} values from \"   host)\n\n      {:ok, result}\n    else\n      :error ->\n        Logger.warn(\"Skipped reconfig, one of MYSQL_{HOST,DB,USER,PASS} is missing\")\n        :ok\n\n      error ->\n        Logger.error(\"Reconfiguring failed. Error: \"   inspect(error))\n        {:error, error}\n    end\n  end\nend\n```","ref":"readme.html#using","title":"Using - Kungfuig","type":"extras"},{"doc":"Simply implement a stub returning an expected config and you are all set.\n\n```elixir\ndefmodule MyApp.Kungfuig.Stub do\n  @moduledoc false\n\n  use Kungfuig.Backend\n\n  @impl Kungfuig.Backend\n  def get(_meta), do: %{foo: :bar, baz: [42]}\nend\n```","ref":"readme.html#testing","title":"Testing - Kungfuig","type":"extras"},{"doc":"- **`0.4.4`** — fix a bug with hardcoded names (`Supervisor` and `Blender`)\n- **`0.4.2`** — allow `imminent: true` option to `Kungfuig.Backend`\n- **`0.4.0`** — allow named `Kungfuig.Supervisor` (thanks @vbroskas)\n- **`0.3.0`** — allow validation through `NimbleOptions` (per backend and global)\n- **`0.2.0`** — scaffold for backends + several callbacks (and the automatic one for `Blender`)\n\n## [Documentation](https://hexdocs.pm/kungfuig)","ref":"readme.html#changelog","title":"Changelog - Kungfuig","type":"extras"}]}